package de.ozgcloud.admin.setting;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.Spy;

import de.ozgcloud.admin.setting.postfach.PostfachSettingBody;
import de.ozgcloud.admin.setting.postfach.PostfachSettingBodyTestFactory;

class SettingMapperTest {
	private final PostfachSettingBody postfach = PostfachSettingBodyTestFactory.create();
	private final AlfaSettingDTO alfaSettingDTO = AlfaSettingDTOTestFactory.create();
	private final VorgangManagerSettingDTO vorgangManagerSettingDTO = VorgangManagerSettingDTOTestFactory.create();

	@Spy
	private final SettingMapper mapper = Mappers.getMapper(SettingMapper.class);

	@Nested
	class TestMapPostfachToAlfaSetting {
		@Test
		void shouldReturnFlattenedAlfaMap() {
			var resultAlfaSetting = mapper.mapAlfaPostfach(AlfaSettingDTO.builder(), postfach).build();

			assertThat(resultAlfaSetting).usingRecursiveComparison().isEqualTo(alfaSettingDTO);
		}
	}

	@Nested
	class TestMapPostfachToVorgangManagerSetting {
		@Test
		void shouldReturnFlattenedVorgangManagerMap() {
			var resultVorgangmanagerSetting = mapper.mapVorgangManagerPostfach(VorgangManagerSettingDTO.builder(), postfach).build();

			assertThat(resultVorgangmanagerSetting).usingRecursiveComparison().isEqualTo(vorgangManagerSettingDTO);
		}
	}

}
